@@ -1,6 +1,5 @@
 import logging
 import pprint
-import sys
 
 from django.conf import settings
 from django.contrib.staticfiles.storage import staticfiles_storage
@@ -10,11 +9,11 @@ from django.urls import NoReverseMatch
 from django.urls import reverse
 from django.utils.encoding import force_str
 from jinja2.nodes import ContextReference
-from jinja2 import Markup
 from jinja2 import TemplateSyntaxError
-from jinja2 import contextfunction
+from jinja2 import pass_context
 from jinja2 import nodes
 from jinja2.ext import Extension
+from markupsafe import Markup
 
 
 JINJA2_MUTE_URLRESOLVE_EXCEPTIONS = getattr(settings, "JINJA2_MUTE_URLRESOLVE_EXCEPTIONS", False)
@@ -94,10 +93,11 @@ class CacheExtension(Extension):
 
     def _cache_support(self, expire_time, fragm_name, vary_on, lineno, caller):
         try:
-            expire_time = int(expire_time)
+            if expire_time is not None:
+                expire_time = int(expire_time)
         except (ValueError, TypeError):
             raise TemplateSyntaxError('"%s" tag got a non-integer timeout '
-                'value: %r' % (list(self.tags)[0], expire_time), lineno)
+                                      'value: %r' % (list(self.tags)[0], expire_time), lineno)
 
         cache_key = make_template_fragment_key(fragm_name, vary_on)
 
@@ -174,7 +174,7 @@ class UrlsExtension(Extension):
         super(UrlsExtension, self).__init__(environment)
         environment.globals["url"] = self._url_reverse
 
-    @contextfunction
+    @pass_context
     def _url_reverse(self, context, name, *args, **kwargs):
         try:
             current_app = context["request"].current_app
